rar

package
v0.0.0-...-55f89e3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 16, 2025 License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Overview

Package rar implements OAuth 2.0 Rich Authorization Requests RFC9396.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type AuthorizationDetail

type AuthorizationDetail struct {
	// Actions is an array of strings representing the kinds of actions to be taken at the resource.
	Actions *[]string `json:"actions,omitempty"`

	// Datatypes is an array of strings representing the kinds of data being requested from the resource.
	Datatypes *[]string `json:"datatypes,omitempty"`

	// Identifier is a string identifier indicating a specific resource available at the API.
	Identifier *string `json:"identifier,omitempty"`

	// Locations is an array of strings representing the location of the resource or resource server (RS). These strings are typically URIs identifying the location of the RS. This field can allow a client to specify a particular RS.
	Locations *[]string `json:"locations,omitempty"`

	// Privileges is an array of strings representing the types or levels of privilege being requested at the resource.
	Privileges *[]string `json:"privileges,omitempty"`

	// Type is an identifier for the authorization details type as a string. The value of the type field determines the allowable contents of the object that contains it. The value is unique for the described API in the context of the authorization server.
	Type string `json:"type"`

	AdditionalProperties map[string]any `json:"-"`
}

AuthorizationDetail is the authorization detail as standardized by the OAuth 2.0 Rich Authorization Requests RFC9396.

func (AuthorizationDetail) AsMap

func (a AuthorizationDetail) AsMap() map[string]any

func (AuthorizationDetail) Equals

Equals reports whether the AuthorizationDetail equals other.

func (AuthorizationDetail) MarshalJSON

func (a AuthorizationDetail) MarshalJSON() ([]byte, error)

MarshalJSON overrides the default JSON handling for AuthorizationDetail to handle AdditionalProperties.

func (*AuthorizationDetail) UnmarshalJSON

func (a *AuthorizationDetail) UnmarshalJSON(b []byte) error

UnmarshalJSON overrides the default JSON handling for AuthorizationDetail to handle AdditionalProperties.

Jump to